@@ -234,13 +234,11 @@ class AudioSignal(TimeSignal):
         if isinstance(in_data, (str, Path)):
             file_path = str(in_data)
             try:
+                file_info = get_file_info(file_path)
                 if samplerate is None:
-                    file_info = get_file_info(file_path)
                     samplerate = file_info.sample_rate
                 decoded_file = decode_file(filename=file_path, output_format=SampleFormat.FLOAT32,
                                            nchannels=1, sample_rate=samplerate)
-                if decoded_file.file_format == FileFormat.UNKNOWN:
-                    raise DecodeError('Unknown file format')
                 samples = np.asarray(decoded_file.samples)
             except DecodeError as decode_error:
                 try:
